@@ -29,9 +29,9 @@ G_BEGIN_DECLS
 #define G_MAXLONG	LONG_MAX
 #define G_MAXULONG	ULONG_MAX
 
-#define G_MININT64	((gint64)  0x8000000000000000)
-#define G_MAXINT64	((gint64)  0x7fffffffffffffff)
-#define G_MAXUINT64	((guint64) 0xffffffffffffffff)
+#define G_MININT64	G_GINT64_CONSTANT(0x8000000000000000)
+#define G_MAXINT64	G_GINT64_CONSTANT(0x7fffffffffffffff)
+#define G_MAXUINT64	G_GINT64_CONSTANT(0xffffffffffffffffU)
 
 typedef signed char gint8;
 typedef unsigned char guint8;
@@ -75,7 +75,7 @@ typedef unsigned int gsize;
 
 #define GLIB_MAJOR_VERSION 2
 #define GLIB_MINOR_VERSION 2
-#define GLIB_MICRO_VERSION 1
+#define GLIB_MICRO_VERSION 3
 
 #define G_OS_UNIX
 
